API docs for “spamfighter.core.commands.command.Command._ParamsWrapper”

# Class s.c.c.c.C._ParamsWrapper(object):

Part of spamfighter.core.commands.command.Command View Source View In Hierarchy

Класс-обертка для проверки корректности сигнатуры параметров или результата команды.

Method | __init__ | Констуктор.
Method | __setattr__ | Undocumented
Method | __getattr__ | Undocumented
Method | checkSignature | Проверить установленность всех необходимых параметров.
Method | getSerialized | Получить сериализованное (до хеша) представление
Method | getUnserialized | Восстанавливаем параметры из сериализованного представления
Method | __prep__ | Undocumented
Method | __str__ | Undocumented

def __init__(self, signature, holder): (source)
Констуктор.

Parameters | signature | сигнатура параметров (type: хеш имя_параметра -> информация о типе параметра и т.п. )
| holder | ссылка на переменную, в которой будут храниться сами проверяемые значения (type: `dict` )

def __setattr__(self, param, value): (source)
Undocumented
def __getattr__(self, param): (source)
Undocumented
def checkSignature(self): (source)
Проверить установленность всех необходимых параметров.

Raises | AttributeError | если какой-то обязательный параметр не задан.

def getSerialized(self): (source)
Получить сериализованное (до хеша) представление массива.

Returns | Deferred (`dict`) (type: `twisted.internet.defer.Deferred` )

def getUnserialized(self, serializedParams): (source)
Восстанавливаем параметры из сериализованного представления

Parameters | serializedParams | сериализованные параметры

def __prep__(self): (source)
Undocumented
def __str__(self): (source)
Undocumented